PRO aver1m,date,iaver,waver

;Normalization and averaging over 1 minute,
;i.e. summing 4 consecutive frames.
;INPUT: filtered and registered movies isi*.bin (IR) and
;	wsi*.bin (WL).
;	date = 23 or 25
;OUTPUT: IAVER, WAVER, IR and WL movies averaged
;	over 1-minute time intervals, to study motions
;	in active regions.

;PARAMETERS:
on_error,1

if (date ne 23) and (date ne 25) then  $
   message,'Sorry, I do not know how to handle this dataset'
dat=strtrim(date,2)

if date eq 23 then begin

  sio=[3,408,320,118]

	lx1=10		; clear subfield
	lx2=397
	ly1=10
	ly2=309
	lz1=7
	lz2=110

	qx1=246		; subfield of quiet region
	qx2=379
	qy1=182
	qy2=291

endif else begin

  sio=[3,388,300,150]

	lx1=10		;clear subfield
	lx2=377
	ly1=10
	ly2=289
	lz1=7
	lz2=142

	qx1=304		; subfield of quiet region
	qx2=363
	qy1=135
	qy2=274

endelse

mov=intarr(sio(1),sio(2),sio(3))


;READING AND TRIMMING DATA - 1st part

print,'reading *a.bin files'
openr,1,'../irdata/isi'+dat+'a.bin'
readu,1,mov
close,1
iino=float(mov(lx1:lx2,ly1:ly2,lz1:lz2))
si=size(iino)

openr,1,'../wldata/wsi'+dat+'a.bin'
readu,1,mov
close,1
wino=float(mov(lx1:lx2,ly1:ly2,lz1:lz2))


;NORMALIZATION AND DIFFERENCE - 1st part

print,'normalizing'
for i=0,si(3)-1 do begin
  iino(0,0,i)=iino(*,*,i)/mean(iino(qx1:qx2,qy1:qy2,i))
  wino(0,0,i)=wino(*,*,i)/mean(wino(qx1:qx2,qy1:qy2,i))
endfor

cwl=stdev(wino(qx1:qx2,qy1:qy2,*))
cir=stdev(iino(qx1:qx2,qy1:qy2,*))
print,'QUIET REGION 1st part:'
print,'WL:  contrast =',cwl
print,'IR:  contrast =',cir
fact=cwl/cir
print,'WL/IR: factor =',fact


;AVERAGING OVER 1-MINUTE INTERVALS (summation of 4 frames)

iaver=fltarr(si(1),si(2),2*si(3)/3)	; OUTPUT arrays
waver=iaver

i=0
while 3*i+3 le si(3)-1 do begin
  iaver(0,0,i)=total(iino(*,*,3*i:3*i+3),3)/4.
  waver(0,0,i)=total(wino(*,*,3*i:3*i+3),3)/4.
  i=i+1
endwhile

n=i					;frames done
print,'First part:',i,' averaged frames'

;-----------------

;READING AND TRIMMING DATA - 2nd part

print,'reading *b.bin files'
openr,1,'../irdata/isi'+dat+'b.bin'
readu,1,mov
close,1
iino=float(mov(lx1:lx2,ly1:ly2,lz1:lz2))
si=size(iino)

openr,1,'../wldata/wsi'+dat+'b.bin'
readu,1,mov
close,1
wino=float(mov(lx1:lx2,ly1:ly2,lz1:lz2))


;NORMALIZATION AND DIFFERENCE - 2nd part

print,'normalizing'
for i=0,si(3)-1 do begin
  iino(0,0,i)=iino(*,*,i)/mean(iino(qx1:qx2,qy1:qy2,i))
  wino(0,0,i)=wino(*,*,i)/mean(wino(qx1:qx2,qy1:qy2,i))
endfor

cwl=stdev(wino(qx1:qx2,qy1:qy2,*))
cir=stdev(iino(qx1:qx2,qy1:qy2,*))
print,'QUIET REGION 2nd part:'
print,'WL:  contrast =',cwl
print,'IR:  contrast =',cir
fact=cwl/cir
print,'WL/IR: factor =',fact


;AVERAGING OVER 1-MINUTE INTERVALS (summation of 4 frames)

i=0
while 3*i+3 le si(3)-1 do begin
  iaver(0,0,i+n)=total(iino(*,*,3*i:3*i+3),3)/4.
  waver(0,0,i+n)=total(wino(*,*,3*i:3*i+3),3)/4.
  i=i+1
endwhile

print,'Second part:',i,' averaged frames'
print,'In total:   ',n+i,' averaged frames'

iaver=iaver(*,*,0:n+i-1)
waver=waver(*,*,0:n+i-1)

END
