PRO binavgc

;The procedure analyses speed classes vs. cdist
;distribution in 10 bins along the relative distance in the
;penumbra and plots it in a .PS figure 'binavgt.ps'.
;Used for Suetterlin's penumbra.
;
; The info is extracted from vxy10i.log, vxy10o.log
; Optional output to ps/eps files.
; 8 February 1999, modified 26 Apr 2000

;reading data

restore,'vxy/vxy10i.log'
restore,'vxy/vxy10o.log'
ddi=reform(vxylogi(3,*))	; distances w.r. to center (")
ddo=reform(vxylogo(3,*))
vi=reform(vxylogi(5,*))		; speed classes
vo=reform(vxylogo(5,*))


;normalization of positions to 0--1 (min--max)

ddi=ddi>7.3	;setting artifitial boundaries at 7.3" and 18.5"
ddi=ddi<18.5	;  to compensate for the slight asymmetry
ddo=ddo>7.3
ddo=ddo<18.5

m0i=min(ddi)
m0o=min(ddo)
m0=m0i<m0o
m1i=max(ddi)
m1o=max(ddo)
m1=m1i>m1o
dni=(ddi-m0)/(m1-m0) < 0.999	;relative distances
dno=(ddo-m0)/(m1-m0) < 0.999

  set_plot,'ps'
  device,filename='binavgc.ps',xsiz=15,ysiz=11,yoffs=14,encapsulated=0
;  device,filename='binavgc.eps',xsiz=15,ysiz=11,yoffs=14,encapsulated=1

  plot,[0],/nodata,xra=[0,1],yra=[-2.8,2.8],/yst,xthick=2,ythick=2, $
   title='Percentage of PGs in a Bin',charsiz=1.1,charthick=2,  $
   ytitle='Speed class', xtitle='Relative Position in the Penumbra'

;bins 0-.1 ... .9 - 1

for i=0,9 do begin
  wi=where(dni ge i/10. and dni lt (i+1)/10.,cii)
  wo=where(dno ge i/10. and dno lt (i+1)/10.,coo)

  hii=histogram(vi(wi),min=(-2),max=2,bin=1)
  hio=histogram(vo(wo),min=(-2),max=2,bin=1)

  thi=total(hii)
  if thi eq 0 then thi=1
  hii=nint(float(hii)/thi*100)
  tho=total(hio)
  if tho eq 0 then tho=1
  hio=nint(float(hio)/tho*100)

;plotting percentages of speed class frequencies

  for j=0,4 do begin
	xyouts,i/10.+0.03,j-2.+0.05,strtrim(hii(j),2),/data
	xyouts,i/10.+0.03,j-2.-0.25,strtrim(hio(j),2),/data
  endfor

endfor

for i=1,9 do plots,[i/10.,i/10.],[-2.8,2.8],/data

  device,/close
  !p.multi=0
  set_plot,'x'

end
