pro pqual,mov,qual

; working version of quality determination using 1-D power spectra
; derived from strips in x,y cross form
; works wit 3-D array MOV (input)
; output: quality measure (integral power) in 3 channels - array QUAL

;--------------------------------------------
stp=0.125	; spatial scale (arcsec/pix)

; settings of 3 channels (char.length in arcsec)
ch=[[0.6,0.35],[0.6,0.4],[0.9,0.4]]
;--------------------------------------------

si=size(mov)
qual=fltarr(3,si(3))

n=si(1)<si(2)	; length of cross arms is the minimum of x,y sizes
cc=[si(1)/2,si(2)/2]	; cc(0), cc(1): cross center coordinates
			; cb(0), cb(1): beginning of cross arms
if si(1) gt n then cb=[(si(1)-n)/2,0] else cb=[0,(si(2)-n)/2]

stf=1/(n*stp)		; step in Fourier domain is n*stp
chp=nint(1/(ch*stf))	; conversion to pixels: (1/ch)/stf
	print,n,'   center=',cc
	print,'begin=',cb
	print,chp
slx=[cc(1)-n/8,cc(1)+n/8]	; strip limits (width = n/4)
sly=[cc(0)-n/8,cc(0)+n/8]

; apodization window
   perc=20.		  ; percentage of frame size to be damped
   np=nint(n*perc/100.)
   u=fltarr(n)+1.
   u(0)=0.
   for i=1,np do u(i)=(1.-cos(!pi*i/np))/2.
   u(n-np:n-1)=reverse(u(1:np))
	plot,u,col=0,back=255

for i=0,si(3)-1 do begin	; loop over frames

;  cx=mov(cb(0):cb(0)+n-1,cc(1),i)	; cross arm in x
;  cy=mov(cc(0),cb(1):cb(1)+n-1,i)	; cross arm in y

; compression of strips to x and y
  cx=total(mov(cb(0):cb(0)+n-1,slx(0):slx(1),i),2)
  cy=total(mov(sly(0):sly(1),cb(1):cb(1)+n-1,i),1)

; apodization

  cx=cx-mean(cx)
  cy=cy-mean(cy)
  cx=cx*u
  cy=cy*u	;apodized frames (mean subtracted)

  fx=fft(cx,-1)
  fy=fft(cy,-1)
  psp=float(fx)^2+imaginary(fx)^2 + float(fy)^2+imaginary(fy)^2

  qual(0,i)=total(psp(chp(0,0):chp(1,0)))	; channel 0
  qual(1,i)=total(psp(chp(0,1):chp(1,1)))	; channel 1
  qual(2,i)=total(psp(chp(0,2):chp(1,2)))	; channel 2

if i eq 0 then plot,psp(chp(0,0):chp(1,0)),back=255,col=0,yra=[0.,3.e5] $
 else oplot,psp(chp(0,0):chp(1,0)),col=3*i

endfor

end
  